@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# Application Name - Health Check V0.9.0-0
+# Application Name - Health Check V1.0.0-0
 # Date 17 February 2010
 # Author - Greg Roberts (Noobmonkey @ Maemo Talk)
 # Contact - Me@Greg-roberts.com
@@ -602,7 +602,7 @@ class Ui_MainWindow(object):
 		# box of some sort
 		self.textBrowser = QtGui.QTextBrowser(self.tab_4)
 		self.textBrowser.setGeometry(QtCore.QRect(0, 10, 781, 301))
-		self.textBrowser.setText (" Health Check V0.9.0-0 \n Greg Roberts (Maemo.org - Noobmonkey) \n me@greg-roberts.com \n \n For Bugs and Feature requests: \n http://talk.maemo.org/showthread.php?p=541457 \n\n Thanks to: Mikec(Accuracy test), Rob1n(App window) & Lcuk(Everything!)\n And to all the testers.")
+		self.textBrowser.setText (" Health Check V1.0.0-0 \n Greg Roberts (Maemo.org - Noobmonkey) \n me@greg-roberts.com \n \n For Bugs and Feature requests: \n http://talk.maemo.org/showthread.php?p=541457 \n\n Thanks to: Mikec, Rob1n, Lcuk, W00t_ & MohammadAG.\n Many more people have helped by testing and offering support, so Thank You. \n \n April 2010.")
 		# Make the font small!!!
 		font = QtGui.QFont()
 		font.setPointSize(20)
@@ -655,6 +655,25 @@ class Ui_MainWindow(object):
 				#print about[0],
 				self.listApps.addItem(about[1])
 				self.listApps.sortItems()
+	def cpufreq(self):
+		print " ** Opening CPU Frequency File**"
+		fh = open("/sys/devices/system/cpu/cpu0/cpufreq/scaling_available_frequencies","r")
+		igot = fh.readlines()
+		print " ** Adding CPUQ Frequencies **"
+		aa = ""
+		for line in igot:
+                        s = line.split()
+                        for words in s:
+                                print words
+                                aa = str(aa) + str((int(words)/1000)) + "MHz, "
+
+                print aa
+                self.listWidget.addItem("CPU Avail Freq \t\t" + aa)
+                                
+                        
+                               
+
+
 				
 		
 		
@@ -1048,11 +1067,6 @@ class Ui_MainWindow(object):
 		gl = gl.strip()
 		self.listWidget.addItem("CPU Current Freq \t\t" + gl.strip())
 		
-		print " ** Getting CPU Frequency **"
-		gl = os.popen('echo $((`cat /sys/devices/system/cpu/cpu0/cpufreq/scaling_max_freq`/1000)) MHz').read()
-		gl = gl.strip()
-		self.listWidget.addItem("CPU Max Freq \t\t" + gl.strip())
-
 		#print " ** Getting CPU Temperature **"
 		#gl = os.popen('cat /sys/devices/platform/omap34xx_temp/temp1_input').read()
 		#gl = gl.strip()
@@ -1088,6 +1102,8 @@ class Ui_MainWindow(object):
 		gl = gl.strip()
 		self.listWidget.addItem("MMC Cover State \t\t" + gl.strip())
 
+		self.cpufreq()
+
 		
 
 
@@ -1109,7 +1125,7 @@ class Ui_MainWindow(object):
 		progress.setWindowTitle("Loading Healthcheck")
 		progress.show()
 		QtGui.QApplication.processEvents()
-		time.sleep(0.5)
+		time.sleep(0.1)
                 progress.setValue(0)
 
                 print " ** Running tab1 update ** "
@@ -1117,32 +1133,32 @@ class Ui_MainWindow(object):
                 self.updaterootfs()
                 progress.setWindowTitle("Loading Healthcheck - Rootfs")
                 QtGui.QApplication.processEvents()
-                time.sleep(0.3)
+                time.sleep(0.1)
                 progress.setValue(15)
                 self.updateAccel()
                 progress.setWindowTitle("Loading Healthcheck - Accelerometer")
                 QtGui.QApplication.processEvents()
-                time.sleep(0.3)
+                time.sleep(0.1)
                 progress.setValue(30)
                 self.updateCPU()
                 progress.setWindowTitle("Loading Healthcheck - CPU")
                 QtGui.QApplication.processEvents()
-                time.sleep(0.3)
+                time.sleep(0.1)
                 progress.setValue(45)
                 self.updateMaemoV()
                 progress.setWindowTitle("Loading Healthcheck - Firmware")
                 QtGui.QApplication.processEvents()
-                time.sleep(0.3)
+                time.sleep(0.1)
                 progress.setValue(60)
                 self.updateUptime()
                 progress.setWindowTitle("Loading Healthcheck - Uptime")
                 QtGui.QApplication.processEvents()
-                time.sleep(0.3)
+                time.sleep(0.1)
                 progress.setValue(70)
                 self.updateBatt()
                 progress.setWindowTitle("Loading Healthcheck - Battery")
                 QtGui.QApplication.processEvents()
-                time.sleep(0.3)
+                time.sleep(0.1)
                 self.listWidget.sortItems()
                 print " ** Finished tab 1 update **"
 
@@ -1151,18 +1167,18 @@ class Ui_MainWindow(object):
 		self.updateGPS(MainWindow)
 		progress.setWindowTitle("Loading Healthcheck - GPS")
 		QtGui.QApplication.processEvents()
-                time.sleep(0.3)
+                time.sleep(0.1)
                 progress.setValue(80)
 		self.Cellular(MainWindow)
 		progress.setWindowTitle("Loading Healthcheck - Cell/Phone")
 		QtGui.QApplication.processEvents()
-                time.sleep(0.3)
+                time.sleep(0.1)
                 progress.setValue(90)
 		self.updatenetname()
 		progress.setWindowTitle("Loading Healthcheck - Networks")
 		self.listWidget2.sortItems()
                 progress.setValue(100)
-                time.sleep(0.3)
+                time.sleep(0.1)
                 print " ** Finished tab 2 update **"
                 print " ** Finished ALL Update **"
 		print 'done'
@@ -1271,7 +1287,7 @@ class Ui_MainWindow(object):
 		
 	# This is the start of the QT Designer translation function - not using the translation function, but left it in, to show it is part of the class   
 	def retranslateUi(self, MainWindow):
-		MainWindow.setWindowTitle(QtGui.QApplication.translate("MainWindow", "Health Check V0.9.0-0", None, QtGui.QApplication.UnicodeUTF8))
+		MainWindow.setWindowTitle(QtGui.QApplication.translate("MainWindow", "Health Check V1.0.0-0", None, QtGui.QApplication.UnicodeUTF8))
 		self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab), QtGui.QApplication.translate("MainWindow", "System", None, QtGui.QApplication.UnicodeUTF8))
 		self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_2), QtGui.QApplication.translate("MainWindow", "Comms", None, QtGui.QApplication.UnicodeUTF8))
 		#self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_3), QtGui.QApplication.translate("MainWindow", "Apps", None, QtGui.QApplication.UnicodeUTF8))
